@@ -124,7 +124,7 @@ void ImportImapSettingsThunderbirdCheckJobTest::shouldImportSieveSettings_data()
         SieveEditorUtil::SieveServerConfig settings;
         settings.sieveImapAccountSettings.setUserName(QStringLiteral("bla@kde.org"));
         settings.sieveImapAccountSettings.setServerName(QStringLiteral("sever.foo.org"));
-        settings.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::EncryptionMode::SslV3_1);
+        settings.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::EncryptionMode::SSLorTLS);
         settings.sieveImapAccountSettings.setAuthenticationType(KSieveUi::SieveImapAccountSettings::Plain);
         settings.sieveImapAccountSettings.setPort(993);
         settings.sieveSettings.userName = QStringLiteral("bla@kde.org");
@@ -138,7 +138,7 @@ void ImportImapSettingsThunderbirdCheckJobTest::shouldImportSieveSettings_data()
         SieveEditorUtil::SieveServerConfig settings;
         settings.sieveImapAccountSettings.setUserName(QStringLiteral("bla@kde.org"));
         settings.sieveImapAccountSettings.setServerName(QStringLiteral("sever.foo.org"));
-        settings.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::EncryptionMode::TlsV1);
+        settings.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::EncryptionMode::STARTTLS);
         settings.sieveImapAccountSettings.setAuthenticationType(KSieveUi::SieveImapAccountSettings::GSSAPI);
         settings.sieveImapAccountSettings.setPort(993);
         settings.sieveSettings.userName = QStringLiteral("bla@kde.org");
