@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -36,7 +36,7 @@
 ImportImapSettingWizard::ImportImapSettingWizard(QWidget *parent)
     : KAssistantDialog(parent)
 {
-    setWindowTitle(i18n("Import IMAP Settings"));
+    setWindowTitle(i18nc("@title:window", "Import IMAP Settings"));
 
     mSearchPage = new ImportImapSettingSearchPage(this);
     mSearchPageItem = new KPageWidgetItem(mSearchPage, i18n("Select Import Settings"));
