@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -70,7 +70,7 @@ void ServerSieveListWidget::modifyServerConfig()
     ServerSieveListWidgetItem *serverSieveListItem = static_cast<ServerSieveListWidgetItem *>(item);
 
     QPointer<ServerSieveSettingsDialog> dlg = new ServerSieveSettingsDialog(this);
-    dlg->setWindowTitle(i18n("Modify Settings"));
+    dlg->setWindowTitle(i18nc("@title:window", "Modify Settings"));
     dlg->setServerSieveConfig(serverSieveListItem->serverConfig());
     if (dlg->exec()) {
         serverSieveListItem->setServerConfig(dlg->serverSieveConfig());
