@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -21,7 +21,7 @@
 #define SIEVEEDITORBOOKMARKS_H
 
 #include <QObject>
-#include <kbookmarkowner.h>
+#include <KBookmarkOwner>
 class KBookmarkMenu;
 class QMenu;
 class KActionCollection;
