@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -20,11 +20,16 @@
 #ifndef SIEVEEDITORCONFIGUREDIALOG_H
 #define SIEVEEDITORCONFIGUREDIALOG_H
 
-#include <QDialog>
+#include <KPageDialog>
 class QCheckBox;
-class QTabWidget;
 class SieveEditorConfigureServerWidget;
-class SieveEditorConfigureDialog : public QDialog
+#ifdef WITH_KUSERFEEDBACK
+namespace KUserFeedback {
+class FeedbackConfigWidget;
+}
+#endif
+
+class SieveEditorConfigureDialog : public KPageDialog
 {
     Q_OBJECT
 public:
@@ -40,7 +45,9 @@ private:
     SieveEditorConfigureServerWidget *mServerWidget = nullptr;
     QCheckBox *mCloseWallet = nullptr;
     QCheckBox *mWrapText = nullptr;
-    QTabWidget *mTabWidget = nullptr;
+#ifdef WITH_KUSERFEEDBACK
+    KUserFeedback::FeedbackConfigWidget *mUserFeedbackWidget = nullptr;
+#endif
 };
 
 #endif // SIEVEEDITORCONFIGUREDIALOG_H
