@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -19,7 +19,7 @@
 
 #include "sieveserversettings.h"
 
-#include <kwallet.h>
+#include <KWallet>
 
 SieveServerSettings::SieveServerSettings(QObject *parent)
     : QObject(parent)
