@@ -17,15 +17,15 @@
    Boston, MA 02110-1301, USA.
 */
 
-
 #ifndef USERFEEDBACKMANAGER_H
 #define USERFEEDBACKMANAGER_H
 
 #include <QObject>
+#include "libsieveeditor_export.h"
 namespace KUserFeedback {
 class Provider;
 }
-class UserFeedBackManager : public QObject
+class LIBSIEVEEDITOR_EXPORT UserFeedBackManager : public QObject
 {
     Q_OBJECT
 public:
